@@ -3,7 +3,7 @@
 ;; Author:  Yoshinari Nomura <nom@quickhack.net>
 ;;
 ;; Created: 2000/02/08
-;; Revised: 2004-05-04 13:48:31
+;; Revised: $Date: 2004/05/04 13:48:31 $
 
 ;;;
 ;;; Commentay:
@@ -33,6 +33,51 @@ in setup time.")
   (FACE-SYMBOL . (PARENT FG BG UNDERLINED FONT STIPPLE)).
 refer to mhc-calendar-hnf-face-alist-internal.")
 
+;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
+;; Message faces.
+
+(defvar mhc-message-face-eof-marker 'mhc-message-face-eof-marker)
+(defvar mhc-message-face-subject 'mhc-message-face-subject)
+
+(defface mhc-message-face-eof-marker
+  '((((class color)
+      (background dark))
+     (:background "aquamarine2"))
+    (((class color)
+      (background light))
+     (:background "aquamarine2"))
+    (t
+     ()))
+  "*Face used by mhc-message-eof-marker."
+  :group 'mhc-faces)
+
+(defface mhc-message-face-subject
+  '((((class color)
+      (background dark))
+     (:foreground "OrangeRed" :bold t))
+    (((class color)
+      (background light))
+     (:foreground "Firebrick" :bold t))
+    (t
+     ()))
+  "*Face used by mhc-message-subject."
+  :group 'mhc-faces)
+
+(defvar mhc-message-font-lock-keywords
+  '(("\\([12][0-9][0-9][0-9]\\)\\([0-1][0-9]\\)\\([0-3][0-9]\\)"
+     (1 font-lock-type-face)
+     (2 font-lock-comment-face)
+     (3 font-lock-builtin-face))
+    ("\\(X-SC-\\(Subject\\|Location\\|Day\\|Time\\|Category\\|Priority\\|Recurrence-Tag\\|Mission-Tag:\\|Cond\\|Duration\\|Alarm\\|Record-Id\\|Sequence\\):\\)"
+     (1 font-lock-keyword-face))
+    ("\\(\\[End of message\\]\\)"
+     (1 mhc-message-face-eof-marker))
+    ("\\(X-SC-Subject:\\) *\\(.*\\)"
+     (1 font-lock-keyword-face)
+     (2 mhc-message-face-subject))
+    ))
+
+
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; for necessary faces.
 
@@ -54,6 +99,7 @@ refer to mhc-calendar-hnf-face-alist-internal.")
     (mhc-summary-face-time      . (nil "yellowgreen" nil))
     (mhc-summary-face-location  . (nil "black"       "paleturquoise"))
     (mhc-summary-face-conflict  . (nil "white"       "purple"))
+    (mhc-summary-face-recurrence . (nil "black"      "green"))
     (mhc-summary-face-secret    . (nil "gray"        nil))
     ;;
     (mhc-minibuf-face-candidate . (nil nil           "yellow"))
@@ -70,7 +116,7 @@ refer to mhc-calendar-hnf-face-alist-internal.")
     (mhc-calendar-hnf-face-uri  . (italic "blue" nil))))
 
 (defmacro mhc-face-put (symbol face)
-  (` (put-text-property 0 (length (, symbol)) 'face (, face) (, symbol))))
+  `(put-text-property 0 (length ,symbol) 'face ,face ,symbol))
 
 (eval-when-compile
   (cond
@@ -78,19 +124,19 @@ refer to mhc-calendar-hnf-face-alist-internal.")
     ;; XEmacs 21.2 (make-face-bold FACE &optional LOCALE TAGS)
     ;; XEmacs 21.1 (make-face-bold FACE &optional LOCALE)
     (defmacro mhc-face/make-face-bold (face)
-      (` (make-face-bold (, face))))
+      `(make-face-bold ,face))
     (defmacro mhc-face/make-face-italic (face)
-      (` (make-face-italic (, face))))
+      `(make-face-italic ,face))
     (defmacro mhc-face/make-face-bold-italic (face)
-      (` (make-face-bold-italic (, face)))))
+      `(make-face-bold-italic ,face)))
    (t
     ;; (make-face-bold FACE &optional FRAME NOERROR)
     (defmacro mhc-face/make-face-bold (face)
-      (` (make-face-bold (, face) nil t)))
+      `(make-face-bold ,face nil t))
     (defmacro mhc-face/make-face-italic (face)
-      (` (make-face-italic (, face) nil t)))
+      `(make-face-italic ,face nil t))
     (defmacro mhc-face/make-face-bold-italic (face)
-      (` (make-face-bold-italic (, face) nil t))))))
+      `(make-face-bold-italic ,face nil t)))))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; make faces from string/symbol
@@ -98,7 +144,7 @@ refer to mhc-calendar-hnf-face-alist-internal.")
 (defun mhc-face-category-to-face (category)
   (if category
       (or (intern-soft (format "mhc-category-face-%s" (downcase category)))
-	  'default)
+          'default)
     'default))
 
 (defun mhc-face-make-face-from-string (string prop &optional overwrite prefix)
@@ -107,18 +153,18 @@ refer to mhc-calendar-hnf-face-alist-internal.")
 
 (defun mhc-face-make-face-from-symbol (symbol prop &optional overwrite)
   (let ((parent  (nth 0 prop))
-	(fg      (nth 1 prop))
-	(bg      (nth 2 prop))
-	(uline   (nth 3 prop))
-	(font    (nth 4 prop))
-	(stipple (nth 5 prop))
-	(face    nil))
-    (if (and (mhc-facep symbol) (not overwrite))
-	symbol
+        (fg      (nth 1 prop))
+        (bg      (nth 2 prop))
+        (uline   (nth 3 prop))
+        (font    (nth 4 prop))
+        (stipple (nth 5 prop))
+        (face    nil))
+    (if (and (facep symbol) (not overwrite))
+        symbol
       (setq face (if parent (copy-face parent symbol) (make-face symbol)))
       (if fg      (set-face-foreground  face fg))
       (if bg      (set-face-background  face bg))
-      (set-face-underline-p face uline)
+      (set-face-underline face uline)
       (if font    (set-face-font        face font))
       (if stipple (set-face-stipple     face stipple))
       face)))
@@ -137,33 +183,33 @@ refer to mhc-calendar-hnf-face-alist-internal.")
 ;; ex. mhc-summary-face + today -> mhc-summary-face-today
 (defun mhc-face-get-effect (face effect)
   (let ((new-face (intern (concat
-			   (symbol-name face) "-"
-			   (symbol-name effect))))
-	effect-list)
-    (if (mhc-facep new-face)
-	()
+                           (symbol-name face) "-"
+                           (symbol-name effect))))
+        effect-list)
+    (if (facep new-face)
+        ()
       (copy-face face new-face)
       (if (setq effect-list (cdr (assq effect mhc-face-effect-alist)))
-	  (let ((fg (nth 0 effect-list))
-		(bg (nth 1 effect-list))
-		(bl (nth 2 effect-list))
-		(it (nth 3 effect-list))
-		(ul (nth 4 effect-list)))
-	    (if fg (set-face-foreground  new-face fg))
-	    (if bg (set-face-background  new-face bg))
-	    (if ul (set-face-underline-p new-face t))
-	    ;;
-	    (if bl (or (mhc-face/make-face-bold new-face)
-		       (and (fboundp 'set-face-bold-p)
-			    (set-face-bold-p new-face t))))
-	    ;;
-	    (if it (or (mhc-face/make-face-italic new-face)
-		       (and (fboundp 'set-face-italic-p)
-			    (set-face-italic-p new-face t)))))))
+          (let ((fg (nth 0 effect-list))
+                (bg (nth 1 effect-list))
+                (bl (nth 2 effect-list))
+                (it (nth 3 effect-list))
+                (ul (nth 4 effect-list)))
+            (if fg (set-face-foreground  new-face fg))
+            (if bg (set-face-background  new-face bg))
+            (if ul (set-face-underline new-face t))
+            ;;
+            (if bl (or (mhc-face/make-face-bold new-face)
+                       (and (fboundp 'set-face-bold-p)
+                            (set-face-bold-p new-face t))))
+            ;;
+            (if it (or (mhc-face/make-face-italic new-face)
+                       (and (fboundp 'set-face-italic-p)
+                            (set-face-italic-p new-face t)))))))
     new-face))
-;; 
+;;
 ;; (make-face-italic  new-face nil t))))
-    
+
 (defsubst mhc-face-get-today-face (face)
   (mhc-face-get-effect face 'today))
 
@@ -175,7 +221,7 @@ refer to mhc-calendar-hnf-face-alist-internal.")
 
 (defun mhc-face-setup ()
   (interactive)
-  (let ((ow (interactive-p)))
+  (let ((ow (called-interactively-p 'interactive)))
     ;;
     (mhc-face-setup-internal mhc-symbol-face-alist          ow)
     (mhc-face-setup-internal mhc-category-face-alist        ow)
@@ -186,39 +232,19 @@ refer to mhc-calendar-hnf-face-alist-internal.")
 (defun mhc-face-setup-internal (alist &optional overwrite)
   (let (lst)
     (while (setq lst (car alist))
-      (cond 
+      (cond
        ((stringp (car lst))
-	(mhc-face-make-face-from-string 
-	 (format "mhc-category-face-%s" (downcase (car lst)))
-	 (cdr lst)
-	 overwrite))
+        (mhc-face-make-face-from-string
+         (format "mhc-category-face-%s" (downcase (car lst)))
+         (cdr lst)
+         overwrite))
        ((symbolp (car lst))
-	(mhc-face-make-face-from-symbol
-	 (car lst)
-	 (cdr lst)
-	 overwrite)))
+        (mhc-face-make-face-from-symbol
+         (car lst)
+         (cdr lst)
+         overwrite)))
       (setq alist (cdr alist)))))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
-;; facep for emacs 19.28
-
-(cond
- ((fboundp 'find-face)
-  (defalias 'mhc-facep 'find-face))
- ((fboundp 'facep)
-  (defalias 'mhc-facep 'facep))
- (t
-  ;; Introduced in Emacs 19.29.
-  (defun mhc-facep (x)
-    "Return non-nil if X is a face name or an internal face vector."
-    (or (and (fboundp 'internal-facep)
-	     (let ((fn 'internal-facep))
-	       ;; Avoid compile warning under old Emacsen.
-	       (funcall fn x)))
-	(and (symbolp x)
-	     (assq x (and (boundp 'global-face-data)
-			  (symbol-value 'global-face-data))))))))
-
 (provide 'mhc-face)
 
 ;;; Copyright Notice:
@@ -229,7 +255,7 @@ refer to mhc-calendar-hnf-face-alist-internal.")
 ;; Redistribution and use in source and binary forms, with or without
 ;; modification, are permitted provided that the following conditions
 ;; are met:
-;; 
+;;
 ;; 1. Redistributions of source code must retain the above copyright
 ;;    notice, this list of conditions and the following disclaimer.
 ;; 2. Redistributions in binary form must reproduce the above copyright
@@ -238,7 +264,7 @@ refer to mhc-calendar-hnf-face-alist-internal.")
 ;; 3. Neither the name of the team nor the names of its contributors
 ;;    may be used to endorse or promote products derived from this software
 ;;    without specific prior written permission.
-;; 
+;;
 ;; THIS SOFTWARE IS PROVIDED BY THE TEAM AND CONTRIBUTORS ``AS IS''
 ;; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 ;; LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
