@@ -1,9 +1,9 @@
-;;; -*- mode: Emacs-Lisp; coding: euc-japan -*-
+;;; -*- mode: Emacs-Lisp; coding: utf-8 -*-
 
 ;; Author:  Yoshinari Nomura <nom@quickhack.net>,
 ;;          TSUCHIYA Masatoshi <tsuchiya@namazu.org>
 ;; Created: 1997/10/12
-;; Revised: 2004-05-06 16:35:12
+;; Revised: $Date: 2004/05/06 16:35:12 $
 
 
 ;;; Commentary:
@@ -17,7 +17,7 @@
 ;; Each MHC-SCHEDULE structure is a vector has a construction as
 ;; follows:
 ;;
-;;     MHC-SCHEDULE ::= [ RECORD CONDITION SUBJECT LOCATION TIME ALARM CATEGORIES PRIORITY REGION ]
+;;     MHC-SCHEDULE ::= [ RECORD CONDITION SUBJECT LOCATION TIME ALARM CATEGORIES PRIORITY REGION RECURRENCE-TAG SEQUENCE]
 ;;     RECORD       ::= MHC-RECORD
 ;;     CONDITION    ::= MHC-LOGIC
 ;;     SUBJECT      ::= string ( represents subject of schedule )
@@ -30,21 +30,25 @@
 ;;     REGION       ::= ( START . END )
 ;;     START        ::= integer ( represents start point of headers of schedule )
 ;;     END          ::= integer ( represents end point of headers of schedule )
+;;     RECURRENCE-TAG ::= string
+;;     SEQUENCE     ::= integer
 
 
 ;;; Codes:
 (defun mhc-schedule-new
-  (record &optional condition subject location time alarm categories priority region)
+  (record &optional condition subject location time alarm categories priority region recurrence-tag sequence)
   "Constructor of MHC-SCHEDULE structure."
   (let ((new (vector record
-		     (or condition (mhc-logic-new))
-		     subject
-		     location
-		     time
-		     alarm
-		     categories
-		     priority
-		     (or region (cons nil nil)))))
+                     (or condition (mhc-logic-new))
+                     subject
+                     location
+                     time
+                     alarm
+                     categories
+                     priority
+                     (or region (cons nil nil))
+                     recurrence-tag
+                     sequence)))
     (mhc-record-set-schedules record (cons new (mhc-record-schedules record)))
     new))
 
@@ -66,6 +70,10 @@
   (if schedule (aref schedule 7)))
 (defsubst mhc-schedule-region (schedule)
   (if schedule (aref schedule 8)))
+(defsubst mhc-schedule-recurrence-tag (schedule)
+  (if schedule (aref schedule 9)))
+(defsubst mhc-schedule-sequence (schedule)
+  (if schedule (aref schedule 10)))
 
 (defmacro mhc-schedule-time-begin (schedule)
   `(car (mhc-schedule-time ,schedule)))
@@ -76,23 +84,6 @@
 (defmacro mhc-schedule-region-end (schedule)
   `(cdr (mhc-schedule-region ,schedule)))
 
-;; Need to be deleted.
-(defsubst mhc-schedule-todo-lank (schedule)
-  (if schedule
-      (mhc-logic-todo (mhc-schedule-condition schedule))))
-
-(defsubst mhc-schedule-todo-deadline (schedule)
-  (and schedule
-       (or (car (mhc-logic/day (mhc-schedule-condition schedule)))
-	   (nth 2 (assq
-		   'mhc-logic/condition-duration
-		   (mhc-logic/and
-		    (mhc-schedule-condition schedule))))
-	   (cadr (assq 
-		  'mhc-logic/condition-duration-end
-		  (mhc-logic/and
-		   (mhc-schedule-condition schedule)))))))
-
 (defmacro mhc-schedule/set-subject (schedule subject)
   `(aset ,schedule 2 ,subject))
 (defmacro mhc-schedule/set-location (schedule location)
@@ -109,7 +100,10 @@
   `(setcar (aref ,schedule 8) ,start))
 (defmacro mhc-schedule/set-region-end (schedule end)
   `(setcdr (aref ,schedule 8) ,end))
-
+(defmacro mhc-schedule/set-recurrence-tag (schedule tag)
+  `(aset ,schedule 9 ,tag))
+(defmacro mhc-schedule/set-sequence (schedule sequence)
+  `(aset ,schedule 10 ,sequence))
 
 (defun mhc-schedule-append-default (schedule default)
   (or (mhc-schedule-subject schedule)
@@ -119,12 +113,14 @@
   (or (mhc-schedule-time schedule)
       (not (mhc-schedule-time default))
       (mhc-schedule/set-time schedule
-			     (mhc-schedule-time-begin default)
-			     (mhc-schedule-time-end default)))
+                             (mhc-schedule-time-begin default)
+                             (mhc-schedule-time-end default)))
   (or (mhc-schedule-alarm schedule)
       (mhc-schedule/set-alarm schedule (mhc-schedule-alarm default)))
   (or (mhc-schedule-categories schedule)
-      (mhc-schedule/set-categories schedule (mhc-schedule-categories default))))
+      (mhc-schedule/set-categories schedule (mhc-schedule-categories default)))
+  (or (mhc-schedule-recurrence-tag schedule)
+      (mhc-schedule/set-recurrence-tag schedule (mhc-schedule-recurrence-tag default))))
 
 
 (defsubst mhc-schedule/time-to-string (minutes)
@@ -136,8 +132,8 @@
     (cond
      ((and (car time) (cdr time))
       (concat (mhc-schedule/time-to-string (car time))
-	      "-"
-	      (mhc-schedule/time-to-string (cdr time))))
+              "-"
+              (mhc-schedule/time-to-string (cdr time))))
      ((car time)
       (mhc-schedule/time-to-string (car time)))
      ((cdr time)
@@ -152,21 +148,23 @@
 (defun mhc-schedule-categories-as-string (schedule)
   (let ((categories (mhc-schedule-categories schedule)))
     (if categories
-	(mapconcat (function identity) categories " ")
+        (mapconcat (function identity) categories " ")
       "")))
 
 
 (defun mhc-schedule-in-category-p (schedule category)
   (and schedule
        (if (listp category)
-	   (catch 'found
-	     (while category
-	       (if (member (downcase (car category)) (mhc-schedule-categories schedule))
-		   (throw 'found t))
-	       (setq category (cdr category))))
-	 (member (downcase category) (mhc-schedule-categories schedule)))))
+           (catch 'found
+             (while category
+               (if (member (downcase (car category)) (mhc-schedule-categories schedule))
+                   (throw 'found t))
+               (setq category (cdr category))))
+         (member (downcase category) (mhc-schedule-categories schedule)))))
 
 
+(defun mhc-schedule-recurrence-tag-as-string (schedule)
+  (or (mhc-schedule-recurrence-tag schedule) ""))
 
 (provide 'mhc-schedule)
 
@@ -178,7 +176,7 @@
 ;; Redistribution and use in source and binary forms, with or without
 ;; modification, are permitted provided that the following conditions
 ;; are met:
-;; 
+;;
 ;; 1. Redistributions of source code must retain the above copyright
 ;;    notice, this list of conditions and the following disclaimer.
 ;; 2. Redistributions in binary form must reproduce the above copyright
@@ -187,7 +185,7 @@
 ;; 3. Neither the name of the team nor the names of its contributors
 ;;    may be used to endorse or promote products derived from this software
 ;;    without specific prior written permission.
-;; 
+;;
 ;; THIS SOFTWARE IS PROVIDED BY THE TEAM AND CONTRIBUTORS ``AS IS''
 ;; AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 ;; LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
