@@ -280,8 +280,8 @@ If optional argument FOR-DRAFT is non-nil, Hilight message as draft message."
       (let ((buffer-read-only nil))
         (goto-char (point-min))
         (erase-buffer)
-	(mhc-insert-file-contents-as-coding-system
-	 mhc-default-coding-system file)
+        (mhc-insert-file-contents-as-coding-system
+         mhc-default-coding-system file)
         (mhc-header-narrowing
           (mhc-header-delete-header
            "^\\(Content-.*\\|Mime-Version\\|User-Agent\\):" 'regexp))
@@ -559,8 +559,8 @@ If BANNER is set, it is printed on the horizontal line."
 (defmacro mhc-line-inserter-setup (inserter format alist)
   `(let (byte-compile-warnings)
      (setq ,inserter
-	   (byte-compile
-	    (list 'lambda ()
+           (byte-compile
+            (list 'lambda ()
 		  (mhc-line-parse-format ,format ,alist))))
      (when (get-buffer "*Compile-Log*")
        (bury-buffer "*Compile-Log*"))
@@ -588,8 +588,8 @@ If BANNER is set, it is printed on the horizontal line."
 (defun mhc-summary-line-insert ()
   "Insert summary line."
   (let ((mhc-tmp-day-face (cond
-                           ((mhc-schedule-in-category-p
-                             mhc-tmp-schedule "holiday")
+                           ((mhc-day-holiday
+                             mhc-tmp-dayinfo)
                             'mhc-category-face-holiday)
                            ((eq (mhc-day-day-of-week
                                  mhc-tmp-dayinfo) 0)
@@ -622,7 +622,7 @@ If BANNER is set, it is printed on the horizontal line."
   (define-key mhc-summary-mode-map "P" 'mhc-goto-prev-year)
 
   (define-key mhc-summary-mode-map "s" 'mhc-rescan-month)
-  (define-key mhc-summary-mode-map "d" 'mhc-delete)
+  (define-key mhc-summary-mode-map "D" 'mhc-delete)
   (define-key mhc-summary-mode-map "c" 'mhc-set-default-category)
   (define-key mhc-summary-mode-map "?" 'mhc-calendar)
   (define-key mhc-summary-mode-map "t" 'mhc-calendar-toggle-insert-rectangle)
@@ -658,6 +658,32 @@ If BANNER is set, it is printed on the horizontal line."
   (use-local-map mhc-summary-mode-map)
   (run-hooks 'mhc-summary-mode-hook))
 
+(defun mhc-summary-buffer-p (&optional buffer)
+  (if buffer
+      (set-buffer buffer))
+  mhc-summary-buffer-current-date-month)
+
+(defun mhc-summary-current-date ()
+  (when (mhc-summary-buffer-p)
+    (let ((dayinfo (get-text-property (point) 'mhc-dayinfo)))
+      (or (and dayinfo (mhc-day-date dayinfo))
+          (save-excursion
+            (end-of-line)
+            (while (and (not (bobp))
+                        (null dayinfo))
+              (or (setq dayinfo (get-text-property (point) 'mhc-dayinfo))
+                  (forward-char -1)))
+            (and dayinfo (mhc-day-date dayinfo)))))))
+
+(defvar mhc-summary-buffer-current-date-month nil
+  "Indicate summary buffer's month. It is also used by mhc-summary-buffer-p")
+(make-variable-buffer-local 'mhc-summary-buffer-current-date-month)
+
+(defun mhc-summary-current-date-month ()
+  mhc-summary-buffer-current-date-month)
+(defalias 'mhc-current-date-month 'mhc-summary-current-date-month)
+
+
 (defun mhc-summary-display-message ()
   (interactive)
   (save-selected-window
